{% extends "layout.html" %}
{% block submenu %}
<ul>
  <li><a href="/my/datasets">&#8592; Go back</a>
  <li class="active corporate-identity-submenu-active">Edit dataset
</ul>
{% endblock %}
{% block body %}
<h1>Your dataset has been submitted for review</h1>
<p>Thank you for submitting your dataset to {{site_name}}.  We received your dataset submission.</p>
<p>A reviewer will contact you about publishing it in the {{site_name}} repository.</p>
<div class="center">
  <a id="create-new-dataset" href="/my/datasets" class="button corporate-identity-standard-button">Go to datasets overview</a>
</div>
{% endblock %}
