{% block dataset_access_request %}
<div id = "content-wrapper">
<p><a id="access-request" class="inline-button open" href="#">Request access to data</a></p>
<div id="access-request-wrapper">
  <label for="access-request-email">E-mail</label>
  <input type="text" id="access-request-email" name="email" {% if my_email %}value="{{my_email}}"{% else %}placeholder="Your e-mail address"{% endif %}
   />
  <label for="access-request-name">Name</label>
  <input type="text" id="access-request-name" name="name" {% if my_name %}value="{{my_name}}"{% else %}placeholder="Your name"{% endif %}
   />
  <input type="hidden" id="access-request-dataset-id" name="dataset_id" value="{{item.container_uuid}}" />
  <input type="hidden" id="access-request-version" name="version" value="{{item.version}}"  />
  <label for="access-request-reason">Reason</label>
  <div id="access-request-reason" class="texteditor"></div>
  <p>Your request will be sent to the owner of the dataset.</p>
  <div class="center">
    <div id="submit-access-request" class="button corporate-identity-standard-button">Send request for access to data</div>
  </div>
</div>
</div>
{% endblock %}
