{% extends "layout.html" %}
{% block body %}
<h1>Git repository</h1>
<p>To access the source code from this Git repository, <code>clone</code> the
  Git repository using the following command:</p>
<pre>git clone {{git_repository_url}}</pre>
{% endblock %}
