{% extends "layout.html" %}
{% block headers %}
<script src="/static/js/jquery-3.6.0.min.js"></script>
<script src="/static/js/jquery.dataTables.min.js"></script>
<link href="/static/css/jquery.dataTables.min.css" rel="stylesheet">
<style>
#reports-table .fa-user-secret { color: #000; }
#reports-table .fa-user-secret:hover { color: #666; }
#reports-table .fa-user-secret:active { color: #999; }
#reports-table { display: none; }
#reports-table_wrapper { margin-top: 1em; }
</style>
<script>
jQuery(document).ready(function () {
    jQuery(".hide-for-javascript").removeClass("hide-for-javascript");
    jQuery("#reports-table").DataTable({
        "order": [],
        columnDefs: [{ orderable: false,  targets: 0 }],
        pageLength: 25
    });
    jQuery("#reports-table").show();
});
</script>
{% endblock %}
{% block submenu %}
<ul>
  <li><a href="/admin/dashboard">Dashboard</a>
  <li><a href="/admin/users">Users</a>
  <li><a href="/admin/exploratory">Exploratory</a>
  <li class="active corporate-identity-submenu-active">Reports
  {% if may_query %}<li><a href="/admin/sparql">Query</a>{% endif %}
  {% if may_review_quotas %}<li><a href="/admin/quota-requests">Quota requests</a>{% endif %}
</ul>
{% endblock %}
{% block body %}
<noscript>
  <p class="no-script">Sorry, this page requires JavaScript to function properly.</p>
</noscript>
<div class="hide-for-javascript">
<h1>The List of Reports</h1>
<table id="reports-table" class="corporate-identity-table">
  <thead><tr><th>Report</th><th>Remark</th></thead>
  <tbody>
    <tr>
      <td><a href="/admin/reports/restricted_datasets">The list of the current restricted_datasets</a></td>
      <td></td>
    </tr>
    <tr>
      <td><a href="/admin/reports/embargoed_datasets">The list of the currrent embargoed datasets</a></td>
      <td></td>
    </tr>
  </tbody>
</table>
</div>
{% endblock %}
