<html>
  <head>
    <meta http-equiv="Content-Type" content="text/html; charset=iso-8859-1">
  </head>
  <body>
    <div style="text-align: center"><img style="width: 250px;" src="{{base_url}}/static/images/logo.png" alt="4TU.ResearchData logo" /></div>
    {% block prebody %}{% endblock %}
    {% block body %}{% endblock %}
  </body>
</html>
