{% extends "layout.html" %}
{% block headers %}
<script src="/static/js/jquery-3.6.0.min.js"></script>
<script src="/static/js/utils.js?cache=1741959850"></script>
<script src="/static/js/admin-dashboard.js"></script>
{% endblock %}
{% block submenu %}
<ul>
  <li class="active corporate-identity-submenu-active">Dashboard
  <li><a href="/admin/users">Users</a>
  <li><a href="/admin/exploratory">Exploratory</a>
  <li><a href="/admin/reports">Reports</a>
  {% if may_query %}<li><a href="/admin/sparql">Query</a>{% endif %}
  {% if may_review_quotas %}<li><a href="/admin/quota-requests">Quota requests</a>{% endif %}
</ul>
{% endblock %}
{% block body %}
<div class="hide-for-javascript">
<h1>Administration dashboard</h1>
<p>Welcome, privileged user.</p>
<h2>Maintenance</h2>
<div class="center">
  <a id="clear-cache" href="/admin/maintenance/clear-cache" class="button corporate-identity-standard-button">Clear cache</a>
  <a id="clear-website-sessions" href="/admin/maintenance/remove-website-sessions" class="button corporate-identity-standard-button">Clear old website logins</a>
  <a id="recalculate-statistics" href="/admin/maintenance/recalculate-statistics" class="button corporate-identity-standard-button">Recalculate statistics</a>
  <a id="repair-missing-dois" href="/admin/maintenance/repair-doi-registrations" class="button corporate-identity-standard-button">Repair {{missing_dois}} missing DOIs</a></div>
</div>
</div>
{% endblock %}
