{% extends "layout.html" %}
{% block submenu %}
<ul>
  <li><a href="/my/collections">&#8592; Go back</a>
  <li class="active corporate-identity-submenu-active">Edit collection
</ul>
{% endblock %}
{% block body %}
<h1>Your collection has been published</h1>
<p>Thank you for publishing your collection to {{site_name}}.</p>
<p><a href="/collections/{{collection_id}}">Click here to view the publication page</a>.</p>
<div class="center">
  <a href="/my/collections" class="button corporate-identity-standard-button">Go to collections overview</a>
</div>
{% endblock %}
