{% extends "email/layout.html" %}
{% block body %}
<h1>Dataset approved and published</h1>

<p>Your dataset with title <strong>{{title}}</strong> has been approved and published.</p>
<p>You can view the dataset <a href="{{base_url}}/datasets/{{container_uuid}}">here</a>.</p>

<p>To refer to your published dataset, we recommend to use the appropriate DOI.</p>

<p>When referring to the dataset or a future update of this dataset, we recommend to use:<br /><code>https://doi.org/{{container_doi}}</code></p>

<p>In case you want to refer to this specific version of your dataset, we recommend to use:<br /><code>https://doi.org/{{versioned_doi}}</code></p>

<p>In case you have published additional documents referring to your dataset, you can add them to the metadata yourself. Find more information about modifying and versioning on <a href="{{base_url}}/info/en/use/publish-cite/after-uploading">this page</a>.</p>

<p>This is an automated message. For further correspondence, either use the <a href="{{base_url}}/feedback">feedback form</a> or contact us by e-mail at <a href="mailto:{{support_email}}">{{support_email}}</a></p>

{% endblock %}
