{% extends "email/layout.html" %}
{% block body %}
<h1>Request for access to dataset.</h1>
<p>{{requester_name}} ({{requester_email}}) has requested access to the data of dataset:<br />
    <a href="https://doi.org/{{doi}}">{{title | safe}}</a>.</p>
<p><strong>Reason:</strong></p>
<hr>
{{reason | safe}}
<hr>
{% if owner_email and recipient_email != owner_email %}
<p><i>This message was sent to {{owner_email}}</i></></p>
{% endif %}
{% endblock %}