.inside-form-table {
    width: 100%;
    max-width: 880pt;
    border: solid 2pt #ccc;
    border-radius: .5em;
    margin-bottom: 1em;
    border-spacing: 0;
}
.inside-form-table thead tr { background: #ccc; border-radius: .5em .5em 0em 0em; }
.inside-form-table thead tr th { color: #000; text-align: left; padding: .5em; z-index: 50; border-top: none; }
.inside-form-table thead tr th:last-child { text-align: right; }
.inside-form-table tbody tr td { padding: .5em; z-index: 50; }
.inside-form-table tbody tr:nth-child(even) { background: #fafafa; }
.inside-form-table tbody tr:nth-child(odd) { background: #fff; }
.inside-form-table tbody tr td:not(:first-child) { max-width: 15px; }
.inside-form-table tbody tr td:first-child {
    text-overflow: ellipsis;
    overflow: hidden;
    white-space: nowrap;
    width: 100%;
    max-width: 572pt;
}
#author-inline-edit-form { border: solid 1pt #111; background: #fff; }
#content-wrapper input[type="text"],
#content-wrapper input[type="datetime-local"],
#content-wrapper input[type="date"],
#content-wrapper textarea,
#content-wrapper .options-wrapper, #groups-wrapper, #access-wrapper, #geolocation-wrapper, #thumbnails-wrapper {
    display: block;
    padding: .7em;
    border: solid 1pt #aaa;
    border-radius: 0em .5em .5em .5em;
    width: 832pt;
    margin-top: 0em;
    margin-bottom: 1em;
    font-size: 13pt;
    background-color: #fff;
}
#content-wrapper h3:first-child { margin-top: 0em; }
#content-wrapper h3 {
    font-size: 1.75em;
    padding: 0em;
    margin: .75em 0em .75em 0em;
}
#content-wrapper select {
    display: block;
    padding: .7em;
    border: solid 1pt #aaa;
    background: #fff;
    border-radius: 0em .5em .5em .5em;
    width: 852pt;
    margin-top: 0em;
    margin-bottom: 1em;
    font-size: 13pt;
}
#content-wrapper label {
    display: inline-block;
    background: #ffeeaa;
    color: #000;
    padding: .5em .5em .25em .5em;
    border-radius: .5em .5em 0em 0em;
    border-top: solid 1pt #d4aa00;
    border-right: solid 1pt #d4aa00;
    border-left: solid 1pt #d4aa00;
    font-weight: bold;
}
#content-wrapper label.no-head {
    display: inline-block;
    background: none;
    font-weight: normal;
    cursor: pointer;
    border: 0pt;
    border-radius: 0pt;
}
#content-wrapper label.inner-head {
    display: inline-block;
    background: #eeeeee;
    border: 0pt;
    font-weight: bold;
    cursor: pointer;
}
#content-wrapper textarea:focus,
#content-wrapper input:focus,
#content-wrapper .texteditor:focus {
    outline: none;
    border: solid 1pt #111;
    background: #fffaea;
}
#content-wrapper select:focus {
    outline: none;
    border: solid 1pt #111;
    background: #fffaea;
}

#content-wrapper .options-wrapper input[type="radio"] { display: none; }
#content-wrapper .options-wrapper label { padding: .5em; border-radius: .5em; user-select: none; }
#content-wrapper .options-wrapper label:hover { cursor: pointer; background: #eee; }
#content-wrapper .options-wrapper input[type="radio"]:checked+label {
    background: #505050;
    color: #fff;
    border-radius: .5em;
    opacity: 1.0 !important;
}
#content-wrapper .options-wrapper input[type="radio"]:disabled+label { opacity: 0.5; cursor: auto; }
.texteditor {
    display: block;
    border: solid 1pt #aaa;
    padding: 0em;
    border-radius: 0em 0em .5em .5em;
    resize: vertical;
    font-size: 1.0em;
    width: 852pt;
    margin-top: 0em;
    margin-bottom: 1em;
    background-color: #fff;
}
.autocomplete {
    border-radius: 0em 0em .5em .5em;
    border: solid 1pt #111;
    width: 850pt;
    margin: 0em 0em 1em 0em;
    padding: 0em;
}
.autocomplete ul { margin: 0em; padding: 0em; }
.autocomplete li { list-style-type: none; margin: 0em; padding: .5em; }
.autocomplete li:nth-child(even) { background: #fafafa; }
.autocomplete li:last-child { border-radius: 0em 0em .5em .5em; }
.input-for-ac {
    border-radius: 0em .5em 0em 0em !important;
    margin-bottom: 0em !important;
    border-bottom: #ddd !important;
    width: 832pt;
}
.a-button a {
    text-decoration: none;
    color: #fff;
    background: #139257;
    border-radius: .5em;
    padding: .5em;
    margin: 1em 0em 1em 0em;
}
.a-button a:hover { background: #18b76d; }
.a-button a:active { background: #107a48; }
.required-field { color: #cc0000; user-select: none; }
.subitem-label { cursor: pointer; user-select: none; }
.subitem-label:hover { cursor: pointer; user-select: none; }
.item-label {
    background: none !important;
    border-radius: .5em !important;
    cursor: pointer;
    user-select: none;
    border: 0pt !important;
}
.multi-list { display: none; border: none; }
.multi-list thead { display: none; }
.form-button {
    margin: 0px;
    display: inline-block;
    padding: .5em;
    border-radius: .5em;
    text-transform: uppercase;
    font-size: 14pt;
    user-select: none;
}
.input-with-button {
    display:flex;
    flex-direction:row;
    padding: 0px;
}
.input-with-button input[type="text"] {
    border: none;
    margin-bottom: 0px;
    border-radius: 0em 0em 0em .5em  !important;
}
.input-with-button a {
    white-space: nowrap;
    background: #666666;
    color: #fff;
    border-radius: .5em;
    margin: 0em 0em 0em 0em;
    vertical-align: middle;
    height: 1.5em;
    border-radius: 0em .5em .5em 0em !important;
}
.input-with-button a:hover { background: #999999; }
a.fa-angle-up { cursor: pointer; }
a.fa-angle-down { cursor: pointer; }
button.ql-link { display: none !important }
