body,html { background-color: {{background_color}}; }
.corporate-identity { color: {{primary_color}}; text-decoration: none; }
.corporate-identity:hover { color: {{primary_color_hover}}; text-decoration: underline; }
.corporate-identity li.active { background: {{primary_color}}; }
.corporate-identity li.active a { color: #ffffff; text-decoration: none; }
.corporate-identity-submenu-active { border-bottom: solid .25em {{primary_color}}; }
.corporate-identity-h1 { border-bottom: 4px dotted {{primary_color}}; }
.corporate-identity-h3 { border-bottom: 4px dotted {{primary_color}}; }
.corporate-identity-h4 { border-bottom: 2px dotted {{primary_color}}; }
.corporate-identity-background { background: {{primary_color}}; }
.corporate-identity-header { border-top: 4px solid {{primary_color}}; }
.corporate-identity-footer { color: #fff; border-bottom: 3px solid {{primary_color}}; background: {{footer_background_color}}; }
.corporate-identity-border { border: solid 2pt {{primary_color}}; }
.corporate-identity-table { width: 100%; max-width: 880pt; border: solid 2pt {{primary_color}}; border-radius: .5em; }
.corporate-identity-table thead tr { background: {{primary_color}}; border-radius: .5em .5em 0em 0em; }
.corporate-identity-table thead tr th { color: {{primary_foreground_color}}; text-align: left; padding: .5em; z-index: 50; border-top: none; white-space: nowrap; min-width: 60pt; }
.corporate-identity-standard-button { background: {{primary_color}} !important; color: #fff; font-weight: bold; text-decoration: none; border: 0 !important; }
.corporate-identity-standard-button:hover { background: {{primary_color_hover}} !important; cursor: pointer; color: #fff; text-decoration: none; border: 0 !important; }
.corporate-identity-standard-button:active { background: {{primary_color_active}} !important; cursor: pointer; color: #fff; text-decoration: none; border: 0 !important; }
.corporate-identity-privilege-button { background: {{privilege_button_color}}; }
#login-button { margin-right: 25px; background: {{primary_color}}; color: #ffffff; }
#login-button:hover { background: {{primary_color_hover}}; cursor: pointer; }
#login-button:active { background: {{primary_color_active}}; cursor: pointer; }
#primary-menu .menu-item-has-children:hover { color: {{primary_color_hover}}; }
#primary-menu li a:hover { color: {{primary_color_hover}}; }
.publish-button a { background: {{primary_color}} !important; }
.publish-button a:hover { background: {{primary_color_hover}} !important; }
.publish-button a:active { background: {{primary_color_active}} !important; }
ul.latest-datasets li a { color: {{primary_color}}; }
ul.latest-datasets li a:hover { color: {{primary_color_hover}}; }
ul.latest-datasets li a:active { color: {{primary_color_active}}; }
#files div.label { margin-bottom: 1em; }
#files ul li a { color: {{primary_color}}; }
#files ul li a:hover { color: {{primary_color_hover}}; }
#files ul li a:active { color: {{primary_color_active}}; }
#files ul li.zip { background: {{primary_color}}; margin-top: 1em; padding: .25em; width: 180px; text-align: center; border-radius: .5em; }
#files ul li.zip a { font-weight: bold; color: #fff; }
#total_size { font-size:12px; color: #fff; font-weight: normal; }
.search-filter-row { padding: 0.8em 0.5em 0.5em 1em; border-left: 0.2em solid {{primary_color}}; background: #f9f9f9; margin-top: 0.5em; }
.search-filter-content input[type="checkbox"] { margin-right: 1em; background: {{primary_color}}; accent-color: {{primary_color}}; height: 1.2em; }
.search-filter-content label:hover { color: {{primary_color_hover}}; }
#search-show-more, #search-show-less { color: {{primary_color_hover}}; cursor: pointer; text-align: center; }
.search-results-pager a:hover { color: {{primary_color_hover}}; }
.loader, .loader-top { background-color: {{background_color}}; }
.h1-suffix { background: {{primary_color }}; user-select: none; }
.h1-suffix:hover { background: {{primary_color_hover }}; }
.h1-suffix:active { background: {{primary_color_active }}; }
.h1-suffix a { text-transform: uppercase; text-decoration: none; color: #fff;  font-weight: bold; }
.h1-suffix a:hover { text-decoration: none; color: #fff;  }
.public-button { background-color: {{primary_color}}; color: #fff; }
.public-button:hover { background-color: {{primary_color_hover}}; color: #fff; }
.public-button:active { background-color: {{primary_color_active}}; color: #fff; }
#wrapper #content #collect, #cite, #versions { border: 2pt solid {{primary_color}}; background-color: #fff; }
{%- if sandbox_message_css %}
.sandbox-message-css { {{sandbox_message_css | safe}} }
{%- endif %}
